@@ -7,10 +7,14 @@ import unittest
 from click.testing import CliRunner
 
 from freud_api_crawler import freud_api_crawler as frd
+from freud_api_crawler import string_utils
 from freud_api_crawler import cli
 
 
 MANIFESTATION_ID = "a10e8c78-adad-4ca2-bfcb-b51bedcd7b58"
+MANIFESTATION_PAGE_ID = "5126755a-eeae-4f53-82f9-aaa3a6fd81a9"
+MANIFESTATION_PAGE_URL = "https://www.freud-edition.net/jsonapi/node/manifestation_\
+seite/5126755a-eeae-4f53-82f9-aaa3a6fd81a9"
 
 
 class TestFreud_api_crawler(unittest.TestCase):
@@ -87,6 +91,31 @@ class TestFreud_api_crawler(unittest.TestCase):
         test_item = frd_obj.md__title
         self.assertEqual(test_item, 'II. Die infantile Sexualität')
 
+    def test_010_FrdManifestation_page(self):
+        """Check loading of manifestation_seite"""
+        frd_obj = self.frd_manifestion_obj
+        for x in [MANIFESTATION_PAGE_ID, MANIFESTATION_PAGE_URL]:
+            page = frd_obj.get_page(page_id=x)
+            test_item = page['data']['id']
+            self.assertEqual(test_item, MANIFESTATION_PAGE_ID)
+
+    def test_011_str_cleaning(self):
+        """test clean_markup function"""
+        frd_obj = self.frd_manifestion_obj
+        page = frd_obj.get_page(page_id=MANIFESTATION_PAGE_ID)
+        body = page['data']['attributes']['body']['processed']
+        test_pattern = string_utils.CLEAN_UP_PATTERNS[0][0]
+        cleaned_body = string_utils.clean_markup(body)
+        self.assertTrue(test_pattern not in cleaned_body)
+
+    def test_012_str_cleaning(self):
+        """test clean_markup function"""
+        frd_obj = self.frd_manifestion_obj
+        page = frd_obj.get_page(page_id=MANIFESTATION_PAGE_ID)
+        result = frd_obj.process_page(page)
+        self.assertEqual(result['id'],  MANIFESTATION_PAGE_ID)
+        self.assertTrue('body' in result.keys())
+
     def test_command_line_interface(self):
         """Test the CLI."""
         runner = CliRunner()
